import unittest
from AcdhArcheAssets.uri_norm_rules import (
    get_rules,
    get_normalized_uri,
    get_norm_id
)

SAMPLES = [
    [
        "http://www.geonames.org/1232324343/linz.html",
        "https://sws.geonames.org/1232324343/"
    ],
    [
        "http://d-nb.info/gnd/4074255-6/",
        "https://d-nb.info/gnd/4074255-6"
    ],
    [
        "https://d-nb.info/gnd/4074255-6",
        "https://d-nb.info/gnd/4074255-6"
    ]
]


URIS = [
    ("http://sws.geonames.org/1232324343/linz.html", "1232324343"),
    ("https://orcid.org/0000-0001-5748-9036", "0000-0001-5748-9036"),
    ("https://viaf.org/viaf/106964661/#Napol%C3%A9on_I,_Emperor_of_the_French,_1769-1821", "106964661"),  # noqa: E501
    ("https://www.geonames.org/1232324343", "1232324343"),
    ("https://www.wikidata.org/wiki/Q2", "Q2"),
    ("http://vocab.getty.edu/page/tgn/7003199", "7003199"),
    ("https://d-nb.info/gnd/4074255-6", "4074255-6")
]


class TestNormalizer(unittest.TestCase):
    def test__001_load_list(self):
        rules = get_rules()
        self.assertEqual(type(rules), list, "should be type 'list' ")

    def test__002_test_patterns(self):
        for x in SAMPLES:
            new_uri = get_normalized_uri(x[0])
            self.assertEqual(x[1], new_uri)

    def test__003_test_id_extraction(self):
        for x in URIS:
            new_uri = get_norm_id(x[0])
            self.assertEqual(x[1], new_uri)



import json
import pkg_resources
import re


def get_rules():
    """ returns a list of regex pattern matches

    :return: a list of regex patterns to normalize Authority IDs
    :rtype: list

    """
    return json.loads(pkg_resources.resource_string(__name__, 'uriNormRules.json'))


def get_normalized_uri(uri):
    """ takes a normdata uri and returns a normlalized version
    :param uri: A normdata uri
    :param type: str

    :return: The normalized URI
    :rtype: str
    """
    for x in get_rules():
        uri = re.sub(x['match'], x['replace'], uri)
    return uri


def get_norm_id(url):
    """ takes a normdata URL, e.g. "https://www.wikidata.org/wiki/Q2" and returns the actual ID "Q2"
    :param url: A normdata URL

    :return: The normdata ID
    :rtype: str
    """
    # ToDo: make the whole code more robust
    uri = get_normalized_uri(url)
    rules = get_rules()
    for x in rules:
        try:
            idd = re.findall(x['match'], uri)[0]
        except IndexError:
            continue
        if isinstance(idd, tuple):
            if len(idd) == 2:
                result = idd[0]
            elif len(idd) == 3:
                result = idd[1]
            else:
                result = "-".join(idd)
        else:
            result = idd
        return str(result)



import unittest
from AcdhArcheAssets.file_formats import get_formats, get_by_mtype, get_by_extension

MTYPE = 'image/png'
EXTENSION = 'png'


class TestNormalizer(unittest.TestCase):
    def test__001_load_list(self):
        items = get_formats()
        self.assertEqual(type(items), list, "should be type 'list' ")

    def test_002_get_by_mtype(self):
        items = get_by_mtype(MTYPE)
        self.assertEqual(type(items), list, "should be list")
        self.assertTrue(EXTENSION in items[0]['extensions'])

    def test_003_get_by_extension(self):
        items = get_by_extension(EXTENSION)
        self.assertEqual(type(items), list, "should be list")
        self.assertTrue(MTYPE in items[0]['MIME_type'])
